AdkLoggerConfig class

Active logger configuration for CLI log setup.

Constructors

AdkLoggerConfig({Level level = Level.info})
Creates logger configuration with an optional level.

Properties

hashCode int
The hash code for this object.
no setterinherited
level Level
Minimum level written by the logger.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited