AgentGraph class

Graph model containing agent, workflow node, and tool relationships.

Constructors

AgentGraph({required List<AgentGraphNode> nodes, required List<(String, String)> edges, Map<(String, String), String>? edgeLabels})
Creates a graph with nodes and directed edges.

Properties

edgeLabels Map<(String, String), String>
Optional labels keyed by directed edge pair.
final
edges List<(String, String)>
Directed edges represented as (from, to) pairs.
final
hashCode int
The hash code for this object.
no setterinherited
nodes List<AgentGraphNode>
All nodes in the graph.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited