ConformanceTestResult class

Aggregate result for one conformance test case.

Constructors

ConformanceTestResult({required ConformanceTestCase testCase, required List<ConformanceTurnResult> turnResults})
Creates a conformance test result.

Properties

hashCode → int
The hash code for this object.
no setterinherited
passed → bool
Whether every turn in this test case passed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testCase → ConformanceTestCase
Source test case metadata.
final
turnResults → List<ConformanceTurnResult>
Per-turn replay results.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited