ServiceRegistry class

Registry of URI-scheme factories for session, artifact, and memory services.

Constructors

ServiceRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createArtifactService(String uri, {Map<String, Object?>? kwargs}) BaseArtifactService?
Creates an artifact service for uri, or null when unregistered.
createMemoryService(String uri, {Map<String, Object?>? kwargs}) BaseMemoryService?
Creates a memory service for uri, or null when unregistered.
createSessionService(String uri, {Map<String, Object?>? kwargs}) BaseSessionService?
Creates a session service for uri, or null when unregistered.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerArtifactService(String scheme, ServiceFactory<BaseArtifactService> factory) → void
Registers an artifact service factory for URI scheme.
registerMemoryService(String scheme, ServiceFactory<BaseMemoryService> factory) → void
Registers a memory service factory for URI scheme.
registerSessionService(String scheme, ServiceFactory<BaseSessionService> factory) → void
Registers a session service factory for URI scheme.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited