App class
App container describing root agent, plugins, and runtime options.
Constructors
-
App({required String name, required BaseAgent rootAgent, List<
BasePlugin> ? plugins, EventsCompactionConfig? eventsCompactionConfig, Object? contextCacheConfig, ResumabilityConfig? resumabilityConfig}) - Creates an app configuration.
Properties
- contextCacheConfig ↔ Object?
-
Optional context cache configuration.
getter/setter pair
- eventsCompactionConfig ↔ EventsCompactionConfig?
-
Optional event-compaction configuration.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
Application name.
getter/setter pair
-
plugins
↔ List<
BasePlugin> -
Plugins attached to app execution.
getter/setter pair
- resumabilityConfig ↔ ResumabilityConfig?
-
Optional resumability configuration.
getter/setter pair
- rootAgent ↔ BaseAgent
-
Root agent for this app.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited