DemoTimeModel class
Lightweight model used by local dev scaffolds before real model setup.
Constructors
- DemoTimeModel()
- Creates a demo model instance.
Properties
- capabilities → LlmCapabilities
-
Self-reported capabilities snapshot for this LLM instance.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- model ↔ String
-
The model identifier sent to the backend.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateContent(
LlmRequest request, {bool stream = false}) → Stream< LlmResponse> -
Generates model responses for
request.override -
maybeAppendUserContent(
LlmRequest request) → void -
Appends a fallback user turn when
requesthas no trailing user content.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited