ReplayPlugin class
Cursor-based helper for replaying recorded CLI turns.
Constructors
- ReplayPlugin(SessionRecording recording)
-
Creates a replay cursor for
recording.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNext → bool
-
Whether at least one unread turn remains.
no setter
- recording → SessionRecording
-
Recording currently bound to this cursor.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
nextTurn(
) → RecordingTurn? - Returns the next recorded turn and advances the cursor.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void - Resets this cursor to the first turn.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited